@@ -24,7 +24,7 @@ our %EXPORT_TAGS = (
 
 our ($GSL_PREC_DOUBLE, $GSL_PREC_SINGLE, $GSL_PREC_APPROX ) = 0..2;
 our $GSL_MODE_DEFAULT = $GSL_PREC_DOUBLE;
-our $VERSION = '0.11_01';
+our $VERSION = '0.13_02';
 
 
 =head1 NAME
@@ -33,19 +33,28 @@ Math::GSL - Perl interface to the  GNU Scientific Library (GSL)
 
 =head1 VERSION
 
-Version 0.11_01
+Version 0.13_02
 
 =cut
 
 =head1 SYNOPSIS
 
-    use Math::GSL::Matrix qw/:all/;
+    use Math::GSL::Matrix;
     my $matrix = Math::GSL::Matrix->new(5,5);   # 5x5 zero matrix
-    $matrix->set_col(0, [1..5])
-           ->set_row(2, [5..9]);
+    # note that columns and rows are zero-based
+    $matrix->set_col(0, [1..5])                 # set *first* column to 1,2,3,4,5
+           ->set_row(2, [5..9]);                # set *third* column to 5,6,7,8,9   
     my @matrix = $matrix->as_list;              # matrix as Perl list
     my $gsl_matrix = $matrix->raw;              # underlying GSL object
 
+    use Math::GSL::RNG;
+    my $rng = Math::GSL::RNG->new;
+    my @random_numbers = map { $rng->get } (1 .. 1000);
+
+    use Math::GSL::Deriv qw/:all/;
+    my $function = sub { my $x=shift; sin($x**2) };
+    my ($status,$val,$err) = gsl_deriv_central($function, 5, 0.01 );
+
 Each GSL subsystem has it's own module. For example, the random number generator
 subsystem is Math::GSL::RNG. Many subsystems have a more Perlish and
 object-oriented frontend which can be used, as the above example shows. The raw
@@ -183,8 +192,8 @@ sub new
 sub subsystems
 {
     return sort qw/
-        Diff         Machine      Statistics
-        Eigen        Matrix       Poly 
+        Diff         Machine      Statistics   
+        Eigen        Matrix       Poly      
         BSpline      Errno        PowInt        
         CBLAS        FFT          Min           IEEEUtils
         CDF          Fit          QRNG
